emperor.scatterplot — Emperor 0.9.51-dev documentation

# emperor.scatterplot

`emperor.` `scatterplot`(df, x=None, y=None, z=None, remote=True)

  Create an Emperor scatter plot from a Pandas DataFrame

  Parameters: | df : pd.DataFrame Pandas DataFrame with the data to display, this includes both metadata and coordinates to position the samples in a 3D space. x, y, z : str, optional Column names in df, to use as first (`x`), second (`y`) and third (`z`) axes in the visualization. If these are not specified, axes are chosen according to the variance (in decremental order). remote : bool Whether the JavaScript resources should be loaded locally or from GitHub
  Returns: | emperor.core.Emperor Emperor object with the numerical data as the ordination attribute and the entire DataFrame as the mf attribute.
  Raises: | ValueError If df is not a PandasDataFrame If x, y or z are missing from df or if they are not numeric columns. If after removing rows with missing data there are fewer than 3 samples.

  See also

  `emperor.core.Emperor`

  Notes

  If a row has missing data, that data pont will be removed from the visualization.